==> ansys_additive_core-0.19.0b26.tar.gz: ansys_additive_core-0.19.0b26/src/ansys/additive/core/misc.py <==
# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Provides miscellaneous utility functions."""

import random
import string


def short_uuid(nchars: int = 12) -> str:
    """Generate a short UUID.

    Parameters
    ----------
    nchars : int, default 12
        Number of characters in the UUID. Only applies if ``nchars`` is greater
        than 6. Using the default, the probability
        of a collision is 1.23e-17 for 1 billion rounds. See
        https://shortunique.id/classes/ShortUniqueId.html#collisionProbability.

    """
    alphabet = string.ascii_letters + string.digits
    nchars = max(6, nchars)
    return "".join(random.choices(alphabet, k=nchars))  # noqa: S311

==> ansys_additive_core-0.20.0b8.tar.gz: ansys_additive_core-0.20.0b8/src/ansys/additive/core/misc.py <==
# Copyright (C) 2023 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Provides miscellaneous utility functions."""

import random
import string


def short_uuid(nchars: int = 12) -> str:
    """Generate a short UUID.

    Parameters
    ----------
    nchars : int, default 12
        Number of characters in the UUID. Only applies if ``nchars`` is greater
        than 6. Using the default, the probability of a collision is 1.23e-17
        for 1 billion rounds.

    """
    alphabet = string.ascii_letters + string.digits
    nchars = max(6, nchars)
    return "".join(random.choices(alphabet, k=nchars))  # noqa: S311
